@@ -14,6 +14,7 @@ enum { FS_DEFAULT, FS_PARTIAL, FS_NONE, FS_FULL };
 enum { FR_TEXTOUT, FR_UNISCRIBE };
 enum { MC_VOID, MC_PASTE, MC_EXTEND, MC_ENTER };
 enum { RC_MENU, RC_PASTE, RC_EXTEND, RC_ENTER };
+enum { BORDER_NORMAL, BORDER_FRAME, BORDER_VOID };
 enum { TR_OFF = 0, TR_LOW = 16, TR_MEDIUM = 32, TR_HIGH = 48, TR_GLASS = -1 };
 enum { FLASH_FRAME = 1, FLASH_BORDER = 2, FLASH_FULL = 4, FLASH_REVERSE = 8 };
 enum { EMOJIS_NONE = 0, EMOJIS_ONE = 1, EMOJIS_NOTO = 2, EMOJIS_APPLE = 3, 
@@ -65,6 +66,7 @@ typedef struct {
   colour sel_fg_colour, sel_bg_colour;
   colour search_fg_colour, search_bg_colour, search_current_colour;
   wstring theme_file;
+  wstring dark_theme;
   wstring background;
   string colour_scheme;
   char transparency;
@@ -80,6 +82,7 @@ typedef struct {
   bool show_hidden_fonts;
   char font_smoothing;
   char font_render;
+  bool dim_as_font;
   bool bold_as_font;
   bool bold_as_colour;
   bool allow_blinking;
@@ -89,6 +92,7 @@ typedef struct {
   bool old_locale;
   int fontmenu;
   wstring tek_font;
+  wstring tab_font;
   // Keys
   bool backspace_sends_bs;
   bool delete_sends_del;
@@ -96,7 +100,7 @@ typedef struct {
   bool altgr_is_alt;
   int ctrl_alt_delay_altgr;
   bool key_alpha_mode;
-  bool old_altgr_detection;
+  char old_altgr_detection;
   int old_modify_keys;
   int format_other_keys;
   bool auto_repeat;
@@ -134,6 +138,7 @@ typedef struct {
   int lines_per_notch;
   wstring mouse_pointer;
   wstring appmouse_pointer;
+  wstring pixmouse_pointer;
   // Selection
   bool input_clears_selection;
   bool copy_on_select;
@@ -144,6 +149,7 @@ typedef struct {
   int copy_as_rtf_font_size;
   bool trim_selection;
   bool allow_set_selection;
+  bool allow_paste_selection;
   int selection_show_size;
   // Window
   int cols, rows;
@@ -152,6 +158,7 @@ typedef struct {
   int max_scrollback_lines;
   char scrollbar;
   char scroll_mod;
+  char border_style;
   bool pgupdn_scroll;
   wstring lang;
   wstring search_bar;
@@ -175,6 +182,9 @@ typedef struct {
   wstring printer;
   bool confirm_exit;
   bool confirm_reset;
+  bool confirm_multi_line_pasting;
+  bool status_line;
+  int status_debug;
   // Command line
   wstring class;
   char hold;
@@ -201,6 +211,7 @@ typedef struct {
   string suppress_nrc;
   string suppress_wheel;
   string filter_paste;
+  int guard_path;
   int bracketed_paste_split;
   int suspbuf_max;
   int printable_controls;
@@ -236,12 +247,14 @@ typedef struct {
   int padding;
   int ligatures;
   int ligatures_support;
+  bool box_drawing;
   int handle_dpichanged;
   int check_version_update;
   string word_chars;
   string word_chars_excl;
   colour ime_cursor_colour;
   colour_pair ansi_colours[16];
+  int max_image_size;
   wstring sixel_clip_char;
   bool short_long_opts;
   bool bold_as_special;
@@ -254,8 +267,6 @@ typedef struct {
   int options_fontsize;
   string old_options;
   bool dim_margins;
-  bool status_line;
-  int status_debug;
   bool old_xbuttons;
   // Legacy
   bool use_system_colours;
@@ -281,8 +292,6 @@ extern void remember_arg(string);
 extern void finish_config(void);
 extern void copy_config(char * tag, config * dst, const config * src);
 extern void apply_config(bool save);
-extern wchar * getregstr(HKEY key, wstring subkey, wstring attribute);
-extern uint getregval(HKEY key, wstring subkey, wstring attribute);
 extern char * save_filename(char * suf);
 // In a configuration parameter list, map tag to value
 extern char * matchconf(char * conf, char * item);
